@@ -2,7 +2,7 @@ from compas_slicer.print_organization import BasePrintOrganizer
 from compas_slicer.pre_processing.preprocessing_utils import topological_sorting as topo_sort
 from compas_slicer.print_organization.curved_print_organization import BaseBoundary
 import compas_slicer
-from compas.geometry import closest_point_on_polyline, distance_point_point, Polyline, Vector, normalize_vector, Point
+from compas.geometry import closest_point_on_polyline, distance_point_point, Polyline, Vector, Point, subtract_vectors, dot_vectors, scale_vector
 import logging
 from compas_slicer.geometry import Path, PrintPoint
 import compas_slicer.utilities as utils
@@ -138,16 +138,19 @@ class InterpolationPrintOrganizer(BasePrintOrganizer):
         for i, path in enumerate(layer.paths):
             layer_ppts['path_%d' % i] = []
 
-            for p in path.points:
+            for k, p in enumerate(path.points):
                 cp = closest_point_on_polyline(p, Polyline(crv_to_check.points))
                 d = distance_point_point(cp, p)
 
-                ppt = PrintPoint(pt=p, layer_height=avg_layer_height, mesh_normal=normals[count])
+                normal = normals[count]
+                ppt = PrintPoint(pt=p, layer_height=avg_layer_height, mesh_normal=normal)
 
                 ppt.closest_support_pt = Point(*cp)
                 ppt.distance_to_support = d
                 ppt.layer_height = max(min(d, max_layer_height), min_layer_height)
-                ppt.up_vector = Vector(*normalize_vector(Vector.from_start_end(cp, p)))
+                ppt.up_vector = self.get_printpoint_up_vector(path, k, normal)
+                if dot_vectors(subtract_vectors(p, ppt.closest_support_pt), ppt.up_vector) < 0:
+                    ppt.up_vector = Vector(*scale_vector(ppt.up_vector, -1))
                 ppt.frame = ppt.get_frame()
 
                 layer_ppts['path_%d' % i].append(ppt)
